@@ -5,12 +5,6 @@ from django.db import models, migrations
 from django.conf import settings
 
 
-def add_initial_data(apps, schema_editor):
-    Format = apps.get_model("report_builder", "Format")
-    Format.objects.get_or_create(name="US Currency", string="${:20,.2f}")
-    Format.objects.get_or_create(name="ISO Date", string="{:%Y-%m-%d}")
-
-
 class Migration(migrations.Migration):
 
     dependencies = [
@@ -29,9 +23,9 @@ class Migration(migrations.Migration):
                 ('field_verbose', models.CharField(max_length=2000)),
                 ('name', models.CharField(max_length=2000)),
                 ('sort', models.IntegerField(null=True, blank=True)),
-                ('sort_reverse', models.BooleanField(default=False, verbose_name='Reverse')),
+                ('sort_reverse', models.BooleanField(default=False, verbose_name=b'Reverse')),
                 ('width', models.IntegerField(default=15)),
-                ('aggregate', models.CharField(blank=True, max_length=5, choices=[('Sum', 'Sum'), ('Count', 'Count'), ('Avg', 'Avg'), ('Max', 'Max'), ('Min', 'Min')])),
+                ('aggregate', models.CharField(blank=True, max_length=5, choices=[(b'Sum', b'Sum'), (b'Count', b'Count'), (b'Avg', b'Avg'), (b'Max', b'Max'), (b'Min', b'Min')])),
                 ('position', models.PositiveSmallIntegerField(null=True, blank=True)),
                 ('total', models.BooleanField(default=False)),
                 ('group', models.BooleanField(default=False)),
@@ -49,7 +43,7 @@ class Migration(migrations.Migration):
                 ('path_verbose', models.CharField(max_length=2000, blank=True)),
                 ('field', models.CharField(max_length=2000)),
                 ('field_verbose', models.CharField(max_length=2000)),
-                ('filter_type', models.CharField(default='icontains', max_length=20, blank=True, choices=[('exact', 'Equals'), ('iexact', 'Equals (case-insensitive)'), ('contains', 'Contains'), ('icontains', 'Contains (case-insensitive)'), ('in', 'in (comma seperated 1,2,3)'), ('gt', 'Greater than'), ('gte', 'Greater than equals'), ('lt', 'Less than'), ('lte', 'Less than equals'), ('startswith', 'Starts with'), ('istartswith', 'Starts with (case-insensitive)'), ('endswith', 'Ends with'), ('iendswith', 'Ends with  (case-insensitive)'), ('range', 'range'), ('week_day', 'Week day'), ('isnull', 'Is null'), ('regex', 'Regular Expression'), ('iregex', 'Reg. Exp. (case-insensitive)')])),
+                ('filter_type', models.CharField(default=b'icontains', max_length=20, blank=True, choices=[(b'exact', b'Equals'), (b'iexact', b'Equals (case-insensitive)'), (b'contains', b'Contains'), (b'icontains', b'Contains (case-insensitive)'), (b'in', b'in (comma seperated 1,2,3)'), (b'gt', b'Greater than'), (b'gte', b'Greater than equals'), (b'lt', b'Less than'), (b'lte', b'Less than equals'), (b'startswith', b'Starts with'), (b'istartswith', b'Starts with (case-insensitive)'), (b'endswith', b'Ends with'), (b'iendswith', b'Ends with  (case-insensitive)'), (b'range', b'range'), (b'week_day', b'Week day'), (b'isnull', b'Is null'), (b'regex', b'Regular Expression'), (b'iregex', b'Reg. Exp. (case-insensitive)')])),
                 ('filter_value', models.CharField(max_length=2000)),
                 ('filter_value2', models.CharField(max_length=2000, blank=True)),
                 ('exclude', models.BooleanField(default=False)),
@@ -64,8 +58,8 @@ class Migration(migrations.Migration):
             name='Format',
             fields=[
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
-                ('name', models.CharField(default='', max_length=50, blank=True)),
-                ('string', models.CharField(default='', help_text='Python string format. Ex ${} would place a $ in front of the result.', max_length=300, blank=True)),
+                ('name', models.CharField(default=b'', max_length=50, blank=True)),
+                ('string', models.CharField(default=b'', help_text=b'Python string format. Ex ${} would place a $ in front of the result.', max_length=300, blank=True)),
             ],
             options={
             },
@@ -76,15 +70,15 @@ class Migration(migrations.Migration):
             fields=[
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                 ('name', models.CharField(max_length=255)),
-                ('slug', models.SlugField(verbose_name='Short Name')),
+                ('slug', models.SlugField(verbose_name=b'Short Name')),
                 ('description', models.TextField(blank=True)),
                 ('created', models.DateField(auto_now_add=True)),
                 ('modified', models.DateField(auto_now=True)),
                 ('distinct', models.BooleanField(default=False)),
-                ('report_file', models.FileField(upload_to='report_files', blank=True)),
+                ('report_file', models.FileField(upload_to=b'report_files', blank=True)),
                 ('report_file_creation', models.DateTimeField(null=True, blank=True)),
                 ('root_model', models.ForeignKey(to='contenttypes.ContentType')),
-                ('starred', models.ManyToManyField(help_text='These users have starred this report for easy reference.', related_name='report_starred_set', to=settings.AUTH_USER_MODEL, blank=True)),
+                ('starred', models.ManyToManyField(help_text=b'These users have starred this report for easy reference.', related_name='report_starred_set', to=settings.AUTH_USER_MODEL, blank=True)),
                 ('user_created', models.ForeignKey(blank=True, editable=False, to=settings.AUTH_USER_MODEL, null=True)),
                 ('user_modified', models.ForeignKey(related_name='report_modified_set', blank=True, editable=False, to=settings.AUTH_USER_MODEL, null=True)),
             ],
@@ -110,5 +104,4 @@ class Migration(migrations.Migration):
             field=models.ForeignKey(to='report_builder.Report'),
             preserve_default=True,
         ),
-        migrations.RunPython(add_initial_data),
     ]
